==> shardingsphere-readwrite-splitting-core-5.0.0-sources.jar: org/apache/shardingsphere/readwritesplitting/yaml/config/rule/YamlReadwriteSplittingDataSourceRuleConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.readwritesplitting.yaml.config.rule;

import lombok.Getter;
import lombok.Setter;
import org.apache.shardingsphere.infra.yaml.config.pojo.YamlConfiguration;

import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

/**
 * Readwrite-splitting data source rule configuration for YAML.
 */
@Getter
@Setter
public final class YamlReadwriteSplittingDataSourceRuleConfiguration implements YamlConfiguration {
    
    private String autoAwareDataSourceName;
    
    private String writeDataSourceName;
    
    private List<String> readDataSourceNames = new ArrayList<>();
    
    private String loadBalancerName;
    
    private Properties props = new Properties();
}

==> shardingsphere-readwrite-splitting-core-5.3.0-sources.jar: org/apache/shardingsphere/readwritesplitting/yaml/config/rule/YamlReadwriteSplittingDataSourceRuleConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.readwritesplitting.yaml.config.rule;

import lombok.Getter;
import lombok.Setter;
import org.apache.shardingsphere.infra.util.yaml.YamlConfiguration;
import org.apache.shardingsphere.readwritesplitting.yaml.config.strategy.YamlDynamicReadwriteSplittingStrategyConfiguration;
import org.apache.shardingsphere.readwritesplitting.yaml.config.strategy.YamlStaticReadwriteSplittingStrategyConfiguration;

/**
 * Readwrite-splitting data source rule configuration for YAML.
 */
@Getter
@Setter
public final class YamlReadwriteSplittingDataSourceRuleConfiguration implements YamlConfiguration {
    
    private YamlStaticReadwriteSplittingStrategyConfiguration staticStrategy;
    
    private YamlDynamicReadwriteSplittingStrategyConfiguration dynamicStrategy;
    
    private String loadBalancerName;
}
